==> hqsoft_core-0.0.19.tar.gz: lib/core_base/biometrics/local_authentication_biometrics.dart <==
import 'package:flutter/services.dart';
import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:local_auth/auth_strings.dart';
import 'package:local_auth/local_auth.dart';

class LocalAuthenticationBiometrics {
  final LocalAuthentication _auth = LocalAuthentication();

  Future<bool> isBiometricAvailable() async {
    bool isAvailable = false;
    try {
      isAvailable = await _auth.canCheckBiometrics;
    } on PlatformException catch (e) {
      print(e);
    }

    isAvailable
        ? print('Biometric is available!')
        : print('Biometric is unavailable.');

    return isAvailable;
  }

  Future<List<BiometricType>> getListOfBiometricTypes() async {
    List<BiometricType> availableBiometrics;
    try {
      availableBiometrics = await _auth.getAvailableBiometrics();
    } on PlatformException catch (e) {
      print(e);
    }
    return availableBiometrics;
  }

  Future<bool> authenticateUser() async {
    bool isAuthenticated = false;
    try {
      List<BiometricType> listBiometricType = await getListOfBiometricTypes();
      if (listBiometricType.length > 0) {
        if (listBiometricType[0] == BiometricType.fingerprint)
          isAuthenticated = await authenticateFingerprint();
        else if (listBiometricType[0] == BiometricType.face)
          isAuthenticated = await authenticateFaceID();
      }
    } on PlatformException catch (e) {
      print(e);
    }
    return isAuthenticated;
  }

  Future<bool> authenticateFingerprint() async {
    bool isAuthenticated = false;

    try {
      if (Utils.isAndroidPlatform()) {
        if (allTranslations.currentLanguage == "vi") {
          const androidStringsVI = const AndroidAuthMessages(
              fingerprintHint: 'Cảm biến vân tay hoặc khuôn mặt',
              fingerprintNotRecognized:
                  'Dấu vân tay hoặc khuôn mặt không được công nhận. Thử lại.',
              fingerprintSuccess: 'Dấu vân tay (khuôn mặt) được công nhận.',
              cancelButton: 'Hủy',
              signInTitle: 'Xác Thực Sinh Trắc Học',
              fingerprintRequiredTitle: 'Yêu Cầu Sinh Trắc Học',
              goToSettingsButton: 'Cài Đặt',
              goToSettingsDescription:
                  'Vui lòng thiết lập vân tay hoặc khuôn mặt của bạn.');
          isAuthenticated = await _auth.authenticateWithBiometrics(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            androidAuthStrings: androidStringsVI,
            stickyAuth: true,
          );
        } else {
          const androidStringsEN = const AndroidAuthMessages(
              fingerprintHint: 'Touch sensor or FaceID',
              fingerprintNotRecognized:
                  'Fingerprint or FaceID not recognized. Try again.',
              signInTitle: 'Biometric Authentication',
              fingerprintRequiredTitle: 'Biometric Requirements',
              goToSettingsButton: 'Cài Đặt',
              goToSettingsDescription:
                  'Fingerprint or FaceID is not set up on your device. Go to '
                  '\'Settings > Security\' to add your fingerprint or faceId.');

          isAuthenticated = await _auth.authenticateWithBiometrics(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            androidAuthStrings: androidStringsEN,
            stickyAuth: true,
          );
        }
      }
      //IOS
      else {
        if (allTranslations.currentLanguage == "vi") {
          const iosStringsVI = const IOSAuthMessages(
              cancelButton: 'Hủy',
              goToSettingsButton: 'Cài Đặt',
              goToSettingsDescription:
                  'Xác thực sinh trắc học không được thiết lập trên thiết bị của bạn. Vui lòng kích hoạt',
              lockOut:
                  'Xác thực sinh trắc học bị vô hiệu hóa. Vui lòng khóa và mở khóa màn hình của bạn để kích hoạt nó');
          isAuthenticated = await _auth.authenticateWithBiometrics(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            iOSAuthStrings: iosStringsVI,
            stickyAuth: true,
          );
        } else {
          isAuthenticated = await _auth.authenticateWithBiometrics(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            stickyAuth: true,
          );
        }
      }
    } on PlatformException catch (e) {
      print(e);
    }
    return isAuthenticated;
  }

  Future<bool> authenticateFaceID() async {
    bool isAuthenticated = false;

    try {
      if (Utils.isAndroidPlatform()) {
        if (allTranslations.currentLanguage == "vi") {
          const androidStringsVI = const AndroidAuthMessages(
              fingerprintHint: '',
              cancelButton: 'Hủy',
              signInTitle: 'Xác Thực Khuôn Mặt',
              fingerprintRequiredTitle: 'Yêu Cầu Nhận Diện Khuôn Mặt',
              goToSettingsButton: 'Cài Đặt',
              goToSettingsDescription:
                  'Vui lòng thiết lập nhận diện khuôn mặt của bạn.');
          isAuthenticated = await _auth.authenticateWithBiometrics(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            androidAuthStrings: androidStringsVI,
            stickyAuth: true,
          );
        } else {
          const androidStringsVI = const AndroidAuthMessages(
              fingerprintHint: '',
              fingerprintNotRecognized: 'Face not recognized. Try again.',
              signInTitle: 'Face Authentication',
              fingerprintRequiredTitle: 'FaceID required',
              goToSettingsDescription:
                  'FaceID is not set up on your device. Go to '
                  '\'Settings > Security\' to add your faceID.');
          isAuthenticated = await _auth.authenticateWithBiometrics(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            androidAuthStrings: androidStringsVI,
            stickyAuth: true,
          );
        }
      } else {
        if (allTranslations.currentLanguage == "vi") {
          const iosStringsVI = const IOSAuthMessages(
              cancelButton: 'Hủy',
              goToSettingsButton: 'Cài Đặt',
              goToSettingsDescription:
                  'Xác thực sinh trắc học không được thiết lập trên thiết bị của bạn. Vui lòng kích hoạt',
              lockOut:
                  'Xác thực sinh trắc học bị vô hiệu hóa. Vui lòng khóa và mở khóa màn hình của bạn để kích hoạt nó');
          isAuthenticated = await _auth.authenticateWithBiometrics(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            iOSAuthStrings: iosStringsVI,
            stickyAuth: true,
          );
        } else {
          isAuthenticated = await _auth.authenticateWithBiometrics(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            stickyAuth: true,
          );
        }
      }
    } on PlatformException catch (e) {
      print(e);
    }
    return isAuthenticated;
  }
}

==> hqsoft_core-0.0.78.tar.gz: lib/core_base/biometrics/local_authentication_biometrics.dart <==
import 'package:flutter/services.dart';
import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:local_auth/auth_strings.dart';
import 'package:local_auth/local_auth.dart';

class LocalAuthenticationBiometrics {
  final LocalAuthentication _auth = LocalAuthentication();

  Future<bool> isBiometricAvailable() async {
    bool isAvailable = false;
    try {
      isAvailable = await _auth.canCheckBiometrics;
    } on PlatformException catch (e) {
      print(e);
    }

    isAvailable
        ? print('Biometric is available!')
        : print('Biometric is unavailable.');

    return isAvailable;
  }

  Future<List<BiometricType>> getListOfBiometricTypes() async {
    List<BiometricType> availableBiometrics = [];
    try {
      availableBiometrics = await _auth.getAvailableBiometrics();
    } on PlatformException catch (e) {
      print(e);
    }
    return availableBiometrics;
  }

  Future<bool> authenticateUser() async {
    bool isAuthenticated = false;
    try {
      List<BiometricType> listBiometricType = await getListOfBiometricTypes();
      if (listBiometricType.length > 0) {
        if (listBiometricType[0] == BiometricType.fingerprint)
          isAuthenticated = await authenticateFingerprint();
        else if (listBiometricType[0] == BiometricType.face)
          isAuthenticated = await authenticateFaceID();
      }
    } on PlatformException catch (e) {
      print(e);
    }
    return isAuthenticated;
  }

  Future<bool> authenticateFingerprint() async {
    bool isAuthenticated = false;

    try {
      if (Utils.isAndroidPlatform()) {
        if (allTranslations.currentLanguage == "vi") {
          const androidStringsVI = const AndroidAuthMessages(
              biometricHint: 'Cảm biến vân tay hoặc khuôn mặt',
              biometricNotRecognized:
                  'Dấu vân tay hoặc khuôn mặt không được công nhận. Thử lại.',
              biometricSuccess: 'Dấu vân tay (khuôn mặt) được công nhận.',
              cancelButton: 'Hủy',
              signInTitle: 'Xác Thực Sinh Trắc Học',
              biometricRequiredTitle: 'Yêu Cầu Sinh Trắc Học',
              goToSettingsButton: 'Cài Đặt',
              goToSettingsDescription:
                  'Vui lòng thiết lập vân tay hoặc khuôn mặt của bạn.');
          isAuthenticated = await _auth.authenticate(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            androidAuthStrings: androidStringsVI,
            stickyAuth: true,
            biometricOnly: true,
          );
        } else {
          const androidStringsEN = const AndroidAuthMessages(
              biometricHint: 'Touch sensor or FaceID',
              biometricNotRecognized:
                  'Fingerprint or FaceID not recognized. Try again.',
              signInTitle: 'Biometric Authentication',
              biometricRequiredTitle: 'Biometric Requirements',
              goToSettingsButton: 'Cài Đặt',
              goToSettingsDescription:
                  'Fingerprint or FaceID is not set up on your device. Go to '
                  '\'Settings > Security\' to add your fingerprint or faceId.');

          isAuthenticated = await _auth.authenticate(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            androidAuthStrings: androidStringsEN,
            stickyAuth: true,
            biometricOnly: true,
          );
        }
      }
      //IOS
      else {
        if (allTranslations.currentLanguage == "vi") {
          const iosStringsVI = const IOSAuthMessages(
              cancelButton: 'Hủy',
              goToSettingsButton: 'Cài Đặt',
              goToSettingsDescription:
                  'Xác thực sinh trắc học không được thiết lập trên thiết bị của bạn. Vui lòng kích hoạt',
              lockOut:
                  'Xác thực sinh trắc học bị vô hiệu hóa. Vui lòng khóa và mở khóa màn hình của bạn để kích hoạt nó');
          isAuthenticated = await _auth.authenticate(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            iOSAuthStrings: iosStringsVI,
            stickyAuth: true,
            biometricOnly: true,
          );
        } else {
          isAuthenticated = await _auth.authenticate(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            stickyAuth: true,
            biometricOnly: true,
          );
        }
      }
    } on PlatformException catch (e) {
      print(e);
    }
    return isAuthenticated;
  }

  Future<bool> authenticateFaceID() async {
    bool isAuthenticated = false;

    try {
      if (Utils.isAndroidPlatform()) {
        if (allTranslations.currentLanguage == "vi") {
          const androidStringsVI = const AndroidAuthMessages(
              biometricHint: '',
              cancelButton: 'Hủy',
              signInTitle: 'Xác Thực Khuôn Mặt',
              biometricRequiredTitle: 'Yêu Cầu Nhận Diện Khuôn Mặt',
              goToSettingsButton: 'Cài Đặt',
              goToSettingsDescription:
                  'Vui lòng thiết lập nhận diện khuôn mặt của bạn.');
          isAuthenticated = await _auth.authenticate(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            androidAuthStrings: androidStringsVI,
            stickyAuth: true,
            biometricOnly: true,
          );
        } else {
          const androidStringsVI = const AndroidAuthMessages(
              biometricHint: '',
              biometricNotRecognized: 'Face not recognized. Try again.',
              signInTitle: 'Face Authentication',
              biometricRequiredTitle: 'FaceID required',
              goToSettingsDescription:
                  'FaceID is not set up on your device. Go to '
                  '\'Settings > Security\' to add your faceID.');
          isAuthenticated = await _auth.authenticate(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            androidAuthStrings: androidStringsVI,
            stickyAuth: true,
            biometricOnly: true,
          );
        }
      } else {
        if (allTranslations.currentLanguage == "vi") {
          const iosStringsVI = const IOSAuthMessages(
              cancelButton: 'Hủy',
              goToSettingsButton: 'Cài Đặt',
              goToSettingsDescription:
                  'Xác thực sinh trắc học không được thiết lập trên thiết bị của bạn. Vui lòng kích hoạt',
              lockOut:
                  'Xác thực sinh trắc học bị vô hiệu hóa. Vui lòng khóa và mở khóa màn hình của bạn để kích hoạt nó');
          isAuthenticated = await _auth.authenticate(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            iOSAuthStrings: iosStringsVI,
            stickyAuth: true,
            biometricOnly: true,
          );
        } else {
          isAuthenticated = await _auth.authenticate(
            localizedReason:
                allTranslations.text("login_screen_authenticated_by_biometric"),
            useErrorDialogs: true,
            stickyAuth: true,
            biometricOnly: true,
          );
        }
      }
    } on PlatformException catch (e) {
      print(e);
    }
    return isAuthenticated;
  }
}
